{% include 'adminlte2/components/_stylesheets/bootstrap.html' %}
{% include 'adminlte2/components/_stylesheets/fontawesome.html' %}
{% include 'adminlte2/components/_stylesheets/datatables.html' %}
{% include 'adminlte2/components/_stylesheets/select2.html' %}
{% include 'adminlte2/components/_stylesheets/adminlte.html' %}
