{% extends 'adminlte2/layouts/fixed.html' %}

{% block no_content_header %}{% endblock no_content_header %}

{% block control_template %}{% endblock control_template %}

{% block footer_template %}{% endblock footer_template %}
