/*
    Custom CSS to fix header dropdown link color for desktop and mobile
    without using .notifications-menu, .messages-menu, or .tasks-menu
*/
.main-header .navbar .dropdown-menu li a {
    color: #777777;
}

.main-header .navbar .dropdown-menu li a:hover {
    background-color: #E1E3E9;
    color: #333333;
}

.main-header .navbar .dropdown-menu li.active a {
    color: #FFFFFF;
}

@media (max-width: 767px) {
    .main-header .navbar .dropdown-menu li a:hover {
        color: #FFFFFF;
    }

    .main-header .navbar .navbar-custom-menu .dropdown-menu li a {
        color: #777777;
    }

    .main-header .navbar .navbar-custom-menu .dropdown-menu li a:hover {
        background-color: #E1E3E9;
        color: #333333;
    }

    .main-header .navbar .navbar-custom-menu .dropdown-menu li.active a {
        color: #FFFFFF;
    }
}

.skin-black .main-header .navbar .dropdown-menu li.active a,
.skin-black-light .main-header .navbar .dropdown-menu li.active a {
    background-color: #222222;
}

.skin-blue .main-header .navbar .dropdown-menu li.active a,
.skin-blue-light .main-header .navbar .dropdown-menu li.active a {
    background: #0073B7;
}

.skin-green .main-header .navbar .dropdown-menu li.active a,
.skin-green-light .main-header .navbar .dropdown-menu li.active a {
    background: #00A65A;
}

.skin-purple .main-header .navbar .dropdown-menu li.active a,
.skin-purple-light .main-header .navbar .dropdown-menu li.active a {
    background: #605CA8;
}

.skin-red .main-header .navbar .dropdown-menu li.active a,
.skin-red-light .main-header .navbar .dropdown-menu li.active a {
    background: #DD4B39;
}

.skin-yellow .main-header .navbar .dropdown-menu li.active a,
.skin-yellow-light .main-header .navbar .dropdown-menu li.active a {
    background: #F39C12;
}
