{% include 'adminlte2/components/_javascripts/jquery.html' %}
{% include 'adminlte2/components/_javascripts/bootstrap.html' %}
{% include 'adminlte2/components/_javascripts/datatables.html' %}
{% include 'adminlte2/components/_javascripts/select2.html' %}
{% include 'adminlte2/components/_javascripts/adminlte.html' %}
