{% extends 'adminlte2/base.html' %}

{% block body_class %}{{ block.super }} layout-top-nav{% endblock body_class %}

{% block content_wrapper %}
    <div class="container">
        {{ block.super }}
    </div>
{% endblock content_wrapper %}

{% block header_template %}
    {% include 'adminlte2/components/header_top_navigation.html' %}
{% endblock header_template %}

{% block footer_template %}
    {% include 'adminlte2/components/footer_top_navigation.html' %}
{% endblock footer_template %}

{% block sidebar_template %}
{% endblock sidebar_template %}
