{% load static %}

{% if ADMINLTE_USE_CDN %}
    <link rel="stylesheet" href="{{ ADMINLTE_CDN_BOOTSTRAP_CSS_CORE }}">
{% elif DEBUG %}
    <link rel="stylesheet" href="{% static 'adminlte2/libs/bootstrap-3.4.1/css/bootstrap.css' %}">
{% else %}
    <link rel="stylesheet" href="{% static 'adminlte2/libs/bootstrap-3.4.1/css/bootstrap.min.css' %}">
{% endif %}
