<aside class="control-sidebar {{ ADMINLTE_CONTROL_STYLE }}">
    <ul class="nav nav-tabs nav-justified control-sidebar-tabs">
        {% block control_items %}
        {% endblock %}
    </ul>
    <div class="tab-content">
        {% block control_tabs %}
        {% endblock control_tabs %}
    </div>
</aside>
<div class="control-sidebar-bg"></div>
