<!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
<!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
<!--[if lt IE 9]>
    {% include 'adminlte2/components/_shim/html5shiv.html' %}
    {% include 'adminlte2/components/_shim/respond.html' %}
<![endif]-->
