{% load static %}

{% if ADMINLTE_USE_CDN %}
    <script src="{{ ADMINLTE_CDN_JQUERY_JS_CORE }}"></script>
{% elif DEBUG %}
    <script src="{% static 'adminlte2/libs/jquery-3.5.1/jquery.js' %}"></script>
{% else %}
    <script src="{% static 'adminlte2/libs/jquery-3.5.1/jquery.min.js' %}"></script>
{% endif %}
