{% load static %}

{% if ADMINLTE_STATIC_ENABLE_FONTAWESOME %}
    {% if ADMINLTE_USE_CDN %}
        <link rel="stylesheet" href="{{ ADMINLTE_CDN_FONTAWESOME_CSS_CORE }}">
    {% elif DEBUG %}
        <link rel="stylesheet" href="{% static 'adminlte2/libs/fontawesome-4.7.0/css/font-awesome.css' %}">
    {% else %}
        <link rel="stylesheet" href="{% static 'adminlte2/libs/fontawesome-4.7.0/css/font-awesome.min.css' %}">
    {% endif %}
{% endif %}
